@@ -11,12 +11,7 @@ import (
 	"k8s.io/client-go/kubernetes"
 )
 
-func AssertNodeTaints(clientset kubernetes.Interface, nodeGroupName string, expectedTaints []corev1.Taint) {
-	nodeList, err := clientset.CoreV1().Nodes().List(context.Background(), metav1.ListOptions{
-		LabelSelector: fmt.Sprintf("%s=%s", api.NodeGroupNameLabel, nodeGroupName),
-	})
-	Expect(err).ToNot(HaveOccurred())
-
+func AssertNodeTaints(nodeList *corev1.NodeList, expectedTaints []corev1.Taint) {
 	//unset the time so the structs can be compared
 	for _, node := range nodeList.Items {
 		for _, t := range node.Spec.Taints {
@@ -30,3 +25,11 @@ func AssertNodeTaints(clientset kubernetes.Interface, nodeGroupName string, expe
 		}
 	}
 }
+
+func ListNodes(clientset kubernetes.Interface, nodeGroupName string) *corev1.NodeList {
+	nodeList, err := clientset.CoreV1().Nodes().List(context.Background(), metav1.ListOptions{
+		LabelSelector: fmt.Sprintf("%s=%s", api.NodeGroupNameLabel, nodeGroupName),
+	})
+	Expect(err).ToNot(HaveOccurred())
+	return nodeList
+}
