@@ -423,7 +423,7 @@ var _ = Describe("(Integration) Create Managed Nodegroups", func() {
 		})
 
 		Context("and creating a nodegroup with an update config", func() {
-			PIt("defining the UpdateConfig field in the cluster config", func() {
+			It("defining the UpdateConfig field in the cluster config", func() {
 				By("creating it")
 				updateConfig := &api.NodeGroupUpdateConfig{
 					MaxUnavailable: aws.Int(2),
@@ -473,7 +473,7 @@ var _ = Describe("(Integration) Create Managed Nodegroups", func() {
 					WithStdin(testutils.ClusterConfigReader(clusterConfig))
 
 				Expect(cmd).To(RunSuccessfullyWithOutputStringLines(
-					ContainElement(ContainSubstring("unchanged fields: the following fields remain unchanged; they are not supported by `eksctl update nodegroup`: Spot")),
+					ContainElement(ContainSubstring("unchanged fields for nodegroup update-config-ng: the following fields remain unchanged; they are not supported by `eksctl update nodegroup`: Spot")),
 				))
 
 				out, err = ctl.EKS().DescribeNodegroup(&awseks.DescribeNodegroupInput{
