@@ -11,11 +11,11 @@ echo "eksctl: running /etc/eks/bootstrap"
   --apiserver-endpoint "${API_SERVER_URL}" \
   --b64-cluster-ca "${B64_CLUSTER_CA}" \
   --dns-cluster-ip "${CLUSTER_DNS}" \
-  --kubelet-extra-args "--register-with-taints=${NODE_TAINTS} --node-labels=${NODE_LABELS}"
+  --kubelet-extra-args "${KUBELET_EXTRA_ARGS}"
 
 echo "eksctl: merging user options into kubelet-config.json"
 trap 'rm -f ${TMP_KUBE_CONF}' EXIT
-jq -s '.[0] * .[1]' "${KUBELET_CONFIG}" "${KUBELET_EXTRA_ARGS}" > "${TMP_KUBE_CONF}"
+jq -s '.[0] * .[1]' "${KUBELET_CONFIG}" "${KUBELET_EXTRA_CONFIG}" > "${TMP_KUBE_CONF}"
 mv "${TMP_KUBE_CONF}" "${KUBELET_CONFIG}"
 
 systemctl daemon-reload
